import { z } from 'zod';
declare const KinesisDataStreamRecordPayload: z.ZodObject<{
    kinesisSchemaVersion: z.ZodString;
    partitionKey: z.ZodString;
    sequenceNumber: z.ZodString;
    approximateArrivalTimestamp: z.ZodNumber;
    data: z.ZodEffects<z.ZodString, any, string>;
}, "strip", z.ZodTypeAny, {
    kinesisSchemaVersion: string;
    partitionKey: string;
    sequenceNumber: string;
    approximateArrivalTimestamp: number;
    data?: any;
}, {
    data: string;
    kinesisSchemaVersion: string;
    partitionKey: string;
    sequenceNumber: string;
    approximateArrivalTimestamp: number;
}>;
declare const KinesisDataStreamRecord: z.ZodObject<{
    eventSource: z.ZodLiteral<"aws:kinesis">;
    eventVersion: z.ZodString;
    eventID: z.ZodString;
    eventName: z.ZodLiteral<"aws:kinesis:record">;
    invokeIdentityArn: z.ZodString;
    eventSourceARN: z.ZodString;
    kinesis: z.ZodObject<{
        kinesisSchemaVersion: z.ZodString;
        partitionKey: z.ZodString;
        sequenceNumber: z.ZodString;
        approximateArrivalTimestamp: z.ZodNumber;
        data: z.ZodEffects<z.ZodString, any, string>;
    }, "strip", z.ZodTypeAny, {
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
        data?: any;
    }, {
        data: string;
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
    }>;
}, "strip", z.ZodTypeAny, {
    eventID: string;
    eventName: "aws:kinesis:record";
    eventVersion: string;
    eventSource: "aws:kinesis";
    eventSourceARN: string;
    invokeIdentityArn: string;
    kinesis: {
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
        data?: any;
    };
}, {
    eventID: string;
    eventName: "aws:kinesis:record";
    eventVersion: string;
    eventSource: "aws:kinesis";
    eventSourceARN: string;
    invokeIdentityArn: string;
    kinesis: {
        data: string;
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
    };
}>;
/**
 * Zod schema for Kinesis Data Stream event
 *
 * @example
 * ```json
 * {
 *   "Records": [
 *     {
 *       "kinesis": {
 *         "kinesisSchemaVersion": "1.0",
 *         "partitionKey": "1",
 *         "sequenceNumber": "49590338271490256608559692538361571095921575989136588898",
 *         "data": "SGVsbG8sIHRoaXMgaXMgYSB0ZXN0Lg==",
 *         "approximateArrivalTimestamp": 1545084650.987
 *       },
 *       "eventSource": "aws:kinesis",
 *       "eventVersion": "1.0",
 *       "eventID": "shardId-000000000006:49590338271490256608559692538361571095921575989136588898",
 *       "eventName": "aws:kinesis:record",
 *       "invokeIdentityArn": "arn:aws:iam::123456789012:role/lambda-role",
 *       "awsRegion": "us-east-2",
 *       "eventSourceARN": "arn:aws:kinesis:us-east-2:123456789012:stream/lambda-stream"
 *     },
 *     {
 *       "kinesis": {
 *         "kinesisSchemaVersion": "1.0",
 *         "partitionKey": "1",
 *         "sequenceNumber": "49590338271490256608559692540925702759324208523137515618",
 *         "data": "VGhpcyBpcyBvbmx5IGEgdGVzdC4=",
 *         "approximateArrivalTimestamp": 1545084711.166
 *       },
 *       "eventSource": "aws:kinesis",
 *       "eventVersion": "1.0",
 *       "eventID": "shardId-000000000006:49590338271490256608559692540925702759324208523137515618",
 *       "eventName": "aws:kinesis:record",
 *       "invokeIdentityArn": "arn:aws:iam::123456789012:role/lambda-role",
 *       "awsRegion": "us-east-2",
 *       "eventSourceARN": "arn:aws:kinesis:us-east-2:123456789012:stream/lambda-stream"
 *     }
 *   ]
 * }
 *```
 * @see {@link types.KinesisDataStreamEvent | KinesisDataStreamEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-event-example}
 *
 */
declare const KinesisDataStreamSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventSource: z.ZodLiteral<"aws:kinesis">;
        eventVersion: z.ZodString;
        eventID: z.ZodString;
        eventName: z.ZodLiteral<"aws:kinesis:record">;
        invokeIdentityArn: z.ZodString;
        eventSourceARN: z.ZodString;
        kinesis: z.ZodObject<{
            kinesisSchemaVersion: z.ZodString;
            partitionKey: z.ZodString;
            sequenceNumber: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            data: z.ZodEffects<z.ZodString, any, string>;
        }, "strip", z.ZodTypeAny, {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        }, {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        eventID: string;
        eventName: "aws:kinesis:record";
        eventVersion: string;
        eventSource: "aws:kinesis";
        eventSourceARN: string;
        invokeIdentityArn: string;
        kinesis: {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        };
    }, {
        eventID: string;
        eventName: "aws:kinesis:record";
        eventVersion: string;
        eventSource: "aws:kinesis";
        eventSourceARN: string;
        invokeIdentityArn: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventID: string;
        eventName: "aws:kinesis:record";
        eventVersion: string;
        eventSource: "aws:kinesis";
        eventSourceARN: string;
        invokeIdentityArn: string;
        kinesis: {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        };
    }[];
}, {
    Records: {
        eventID: string;
        eventName: "aws:kinesis:record";
        eventVersion: string;
        eventSource: "aws:kinesis";
        eventSourceARN: string;
        invokeIdentityArn: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }[];
}>;
export { KinesisDataStreamSchema, KinesisDataStreamRecord, KinesisDataStreamRecordPayload, };
//# sourceMappingURL=kinesis.d.ts.map