/**
 * Custom parsing error that wraps any erros thrown during schema or envelope parsing.
 * The cause of the error is included in the message, if possible.
 */
declare class ParseError extends Error {
    /**
     * we use the `cause` property, which is present in ES2022 or newer, to store the cause of the error.
     * because we have to support Node 16.x, we need to add this property ourselves.
     * We can remove this once we drop support for Node 16.x.
     * see: https://github.com/aws-powertools/powertools-lambda-typescript/issues/2223
     *
     * @see https://nodejs.org/api/errors.html#errors_error_cause
     */
    readonly cause: Error | undefined;
    constructor(message: string, cause?: Error);
}
export { ParseError };
//# sourceMappingURL=errors.d.ts.map